OC.L10N.register(
    "core",
    {
    "Please select a file." : "Pasirinkite failą.",
    "File is too big" : "Failas yra per didelis",
    "The selected file is not an image." : "Pasirinktas failas nėra paveikslas.",
    "The selected file cannot be read." : "Nepavyksta perskaityti pasirinkto failo.",
    "The file was uploaded" : "Failas buvo įkeltas",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Įkeliamas failas viršija upload_max_filesize direktyvą, esančią faile php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Įkeltas failas viršija MAX_FILE_SIZE direktyvą, kuri buvo nurodyta HTML formoje",
    "The file was only partially uploaded" : "Failas buvo tik dalinai įkeltas",
    "No file was uploaded" : "Nebuvo įkeltas joks failas",
    "Missing a temporary folder" : "Trūksta laikinojo aplanko",
    "Could not write file to disk" : "Nepavyko rašyti į diską",
    "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
    "Invalid file provided" : "Pateiktas neteisingas failas",
    "No image or file provided" : "Nenurodytas paveikslas ar failas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
    "Invalid image" : "Netinkamas paveikslas",
    "State token does not match" : "Išorinės sistemos leidimai nesutampa su turimais.",
    "Invalid app password" : "Neteisingas programėlės slaptažodis",
    "Could not complete login" : "Nepavyko užbaigti prisijungimo",
    "Your login token is invalid or has expired" : "Jūsų prieigos raktas yra neteisingas arba pasibaigė jo galiojimo laikas",
    "Login" : "Prisijungti",
    "Unsupported email length (>255)" : "Nepalaikomas el. pašto žinutės ilgis (>255)",
    "Password reset is disabled" : "Slaptažodžio atstatymas išjungtas",
    "Could not reset password because the token is expired" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas nebegalioja",
    "Could not reset password because the token is invalid" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas yra neteisingas",
    "Password is too long. Maximum allowed length is 469 characters." : "Slaptažodis per ilgas. Didžiausias leistinas ilgis yra 469 simboliai.",
    "%s password reset" : "%s slaptažodžio atstatymas",
    "Password reset" : "Slaptažodžio atstatymas",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite mygtuką slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite nuorodą slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
    "Reset your password" : "Atkurkite savo slaptažodį",
    "Task not found" : "Užduotis nerasta",
    "Internal error" : "Vidinė klaida",
    "Not found" : "Nerasta",
    "Bad request" : "Bloga užklausa",
    "Image not found" : "Paveikslėlis nerastas",
    "Could not detect language" : "Nepavyko aptikti kalbos",
    "Unable to translate" : "Nepavyko išversti",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Pataisymo žingsnis:",
    "Repair info:" : "Pataisymo informacija:",
    "Repair warning:" : "Taisymo įspėjimas:",
    "Repair error:" : "Taisymo klaida:",
    "Nextcloud Server" : "Nextcloud serveris",
    "Learn more ↗" : "Sužinokite daugiau ↗",
    "Preparing update" : "Ruošiamas atnaujinimas",
    "Turned on maintenance mode" : "Įjungta techninės priežiūros veiksena",
    "Turned off maintenance mode" : "Išjungta techninės priežiūros veiksena",
    "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
    "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
    "Updated database" : "Atnaujinta duomenų bazė",
    "Update app \"%s\" from App Store" : "Atnaujinkite programą \"%s\" iš „App Store“. ",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tikrinama ar %s duomenų bazės struktūra gali būti atnaujinta (priklausomai nuo duomenų bazės dydžio, tai gali ilgai užtrukti)",
    "Updated \"%1$s\" to %2$s" : "Atnaujinta „%1$s“ į %2$s",
    "Set log level to debug" : "Žurnalo išvesties lygis nustatytas į derinimo",
    "Reset log level" : "Atstatytas registravimo lygis",
    "Starting code integrity check" : "Pradedama kodo vientisumo patikra",
    "Finished code integrity check" : "Kodo vientisumo patikra užbaigta",
    "%s (incompatible)" : "%s (nesuderinama)",
    "The following apps have been disabled: %s" : "Šios programėlės buvo išjungtos: %s",
    "Already up to date" : "Naudojama naujausia versija",
    "Unknown" : "Nežinoma",
    "PNG image" : "PNG paveikslas",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Vykdomas atnaujinimas, palikus šį puslapį atvertą, kai kuriose aplinkose šis procesas gali būti nutrauktas.",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "An error occurred." : "Įvyko klaida.",
    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
    "Continue to {productName}" : "Tęsti {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
    "Applications menu" : "Programų meniu",
    "Apps" : "Programėlės",
    "More apps" : "Daugiau programėlių",
    "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
    "No" : "Ne",
    "Yes" : "Taip",
    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
    "Create share" : "Sukurti viešinį",
    "Please copy the link manually:" : "Nukopijuokite nuorodą rankiniu būdu:",
    "Clear search" : "Išvalyti paiešką",
    "Start typing to search" : "Rašykite norėdami atlikti paiešką",
    "Today" : "Šiandien",
    "Last 7 days" : "Paskutinės 7 dienos",
    "Last 30 days" : "Paskutinės 30 dienų",
    "Date" : "Data",
    "People" : "Žmonės",
    "Results" : "Rezultatai",
    "Load more results" : "Įkelti daugiau rezultatų",
    "Log in" : "Prisijungti",
    "Log in to {productName}" : "Prisijunkite prie {productName}",
    "Wrong login or password." : "Neteisingas prisijungimas ar slaptažodis.",
    "This account is disabled" : "Ši paskyra yra išjungta",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
    "Account name or email" : "Paskyros vardas ar el. paštas",
    "Account name" : "Paskyros pavadinimas",
    "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
    "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
    "An internal error occurred." : "Įvyko vidinė klaida.",
    "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
    "Password" : "Slaptažodis",
    "Log in with a device" : "Prisijungti naudojant įrenginį",
    "Login or email" : "Prisijungimas ar el. paštas",
    "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
    "Your connection is not secure" : "Jūsų ryšys nėra saugus",
    "Passwordless authentication is only available over a secure connection." : "Tapatybės nustatymas be slaptažodžio yra prieinamas tik per saugų ryšį.",
    "Browser not supported" : "Naršyklė nepalaikoma",
    "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
    "Reset password" : "Atstatyti slaptažodį",
    "Back to login" : "Grįžti prie prisijungimo",
    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
    "New password" : "Naujas slaptažodis",
    "I know what I'm doing" : "Aš žinau ką darau",
    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
    "Recommended apps" : "Rekomenduojamos programėlės",
    "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
    "Cannot install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
    "Cannot install this app" : "Nepavyksta įdiegti šios programėlės",
    "Skip" : "Praleisti",
    "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
    "Away" : "Atsitraukęs",
    "Busy" : "Užimtas laikas",
    "Do not disturb" : "Netrukdyti",
    "Mute all notifications" : "Išjungti visus pranešimus",
    "Invisible" : "Nematomas",
    "Appear offline" : "Atrodyti atsijungusiu",
    "Settings menu" : "Nustatymų meniu",
    "Search contacts" : "Ieškoti adresatų",
    "Reset search" : "Atstatyti paiešką",
    "Could not load your contacts" : "Nepavyko įkelti jūsų adresatų",
    "No contacts found" : "Adresatų nerasta",
    "Show all contacts" : "Rodyti visus adresatus",
    "Install the Contacts app" : "Įdiegti adresatų programėlę",
    "Search" : "Ieškoti",
    "No results for {query}" : "{query} negrąžino jokių rezultatų",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
    "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
    "Search for {name} only" : "Ieškoti tik {name}",
    "Forgot password?" : "Pamiršote slaptažodį?",
    "Back" : "Atgal",
    "More actions" : "Daugiau veiksmų",
    "Security warning" : "Saugumo įspėjimas",
    "Storage & database" : "Saugykla ir duomenų bazė",
    "Data folder" : "Duomenų aplankas",
    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
    "Performance warning" : "Sistemos našumo problemos perspėjimas",
    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
    "Database user" : "Duomenų bazės naudotojas",
    "Database password" : "Duomenų bazės slaptažodis",
    "Database name" : "Duomenų bazės pavadinimas",
    "Database tablespace" : "Duomenų bazės loginis saugojimas",
    "Database host" : "Duomenų bazės serveris",
    "Install" : "Įdiegti",
    "Need help?" : "Reikia pagalbos?",
    "See the documentation" : "Žiūrėkite dokumentaciją",
    "This browser is not supported" : "Ši naršyklė nepalaikoma",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Jūsų naršyklė yra nepalaikoma. Atnaujinkite į naujesnę versiją arba naudokite palaikomą naršyklę.",
    "Continue with this unsupported browser" : "Tęsti naudojant šią nepalaikomą naršyklę",
    "Supported versions" : "Palaikomos versijos",
    "Choose {file}" : "Pasirinkti{file}",
    "Choose" : "Pasirinkti",
    "Copy to {target}" : "Kopijuoti į {target}",
    "Copy" : "Kopijuoti",
    "Move to {target}" : "Perkelti į {target}",
    "Move" : "Perkelti",
    "OK" : "Gerai",
    "read-only" : "tik skaitymui",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} failų konfliktas","{count} failų konfliktai","{count} failų konfliktų","{count} failų konfliktas"],
    "One file conflict" : "Vieno failo konfliktas",
    "New Files" : "Nauji failai",
    "Already existing files" : "Jau esami failai",
    "Which files do you want to keep?" : "Kuriuos failus norite pasilikti?",
    "If you select both versions, the copied file will have a number added to its name." : "Jei pasiliekate abi versijas, prie nukopijuoto failo pavadinimo bus pridėtas skaičius.",
    "Cancel" : "Atsisakyti",
    "Continue" : "Tęsti",
    "(all selected)" : "(visi pažymėti)",
    "({count} selected)" : "({count} pažymėtų)",
    "Error loading file exists template" : "Klaida įkeliant saugykloje esančių rinkmenų ruošinį",
    "Saving …" : "Įrašoma…",
    "seconds ago" : "prieš keletą sekundžių",
    "Connection to server lost" : "Ryšys su serveriu nutrūko",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundžių","Problemos, įkeliant puslapį. Įkeliama iš naujo po %n sekundės"],
    "Add to a project" : "Pridėti į projektą",
    "Show details" : "Rodyti išsamiau",
    "Hide details" : "Slėpti išsamesnę informaciją",
    "Rename project" : "Pervadinti projektą",
    "Failed to rename the project" : "Nepavyko pervadinti projekto",
    "Failed to create a project" : "Nepavyko sukurti projekto",
    "Failed to add the item to the project" : "Nepavyko pridėti elemento į projektą",
    "Connect items to a project to make them easier to find" : "Susieti elementus su projektu, kad juos būtų lengviau rasti",
    "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
    "New in" : "Nauja",
    "View changelog" : "Rodyti keitinių žurnalą",
    "Personal" : "Asmeniniai",
    "Accounts" : "Paskyros",
    "Admin" : "Administravimas",
    "Help" : "Pagalba",
    "Access forbidden" : "Prieiga uždrausta",
    "Back to %s" : "Atgal į %s",
    "Page not found" : "Puslapis nerastas",
    "Too many requests" : "Per daug užklausų",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
    "Error" : "Klaida",
    "Internal Server Error" : "Vidinė serverio klaida",
    "The server was unable to complete your request." : "Serveriui nepavyko įvykdyti jūsų užklausos.",
    "If this happens again, please send the technical details below to the server administrator." : "Jei tai pasikartos, prašome nusiųsti serverio administratoriui žemiau esančią techninę informaciją.",
    "More details can be found in the server log." : "Detalesnė informacija yra sistemos žurnale.",
    "For more details see the documentation ↗." : "Išsamesnei informacijai žiūrėkite dokumentaciją ↗.",
    "Technical details" : "Techniniai duomenys",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Type: %s" : "Tipas: %s",
    "Code: %s" : "Kodas: %s",
    "Message: %s" : "Žinutė: %s",
    "File: %s" : "Failas: %s",
    "Line: %s" : "Eilutė: %s",
    "Trace" : "Sekti",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nepavyko iš konfigūracijos aplanko pašalinti failo CAN_INSTALL. Pašalinkite šį failą rankiniu būdu.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Sistemos veikimui reikalingas JavaScript palaikymas. Prašome {linkstart}įjungti JavaScript palaikymą{linkend} ir atnaujinti puslapį.",
    "Skip to main content" : "Pereiti į pagrindinį turinį",
    "Skip to navigation of app" : "Pereiti į programėlės naršymą",
    "Go to %s" : "Pereiti į %s",
    "Get your own free account" : "Gaukite nemokamą asmeninę paskyrą",
    "Connect to your account" : "Prisijunkite prie paskyros",
    "Please log in before granting %1$s access to your %2$s account." : "Prieš suteikdami %1$s prieigą prie savo %2$s paskyros, prisijunkite.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jeigu nebandote nusistatyti naujo įrenginio ar programėlės, tuomet kažkas bando jus apgauti, kad suteiktumėte jam prieigą prie savo duomenų. Tokiu atveju netęskite ir, vietoj to, susisiekite su savo sistemos administratoriumi.",
    "Grant access" : "Suteikti prieigą",
    "Account access" : "Paskyros prieiga",
    "Currently logged in as %1$s (%2$s)." : "Šiuo metu prisijungta kaip %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Ketinate suteikti %1$s prieigą prie savo %2$s paskyros.",
    "Account connected" : "Paskyra prijungta",
    "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
    "You can close this window." : "Galite užverti šį langą.",
    "Previous" : "Ankstesnis",
    "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
    "Email address" : "El. pašto adresas",
    "Password sent!" : "Slaptažodis išsiųstas!",
    "Two-factor authentication" : "Dviejų faktorių tapatybės nustatymas",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nepavyko įkelti bent vieno iš jūsų įjungtų dviejų faktorių tapatybės nustatymo metodų. Susisiekite su savo administratoriumi.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Susisiekite su savo administratoriumi dėl pagalbos. ",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Tęskite, norėdami nustatyti dviejų faktorių tapatybės nustatymą.",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dviejų faktorių tapatybės nustatymas yra priverstinis, tačiau nebuvo sukonfigūruotas jūsų paskyroje. Norėdami prisijungti, naudokite vieną iš savo atsarginių kodų arba susisiekite su savo administratoriumi dėl pagalbos. ",
    "Use backup code" : "Naudoti atsarginį kodą",
    "Cancel login" : "Atsisakyti prisijungimo",
    "Error while validating your second factor" : "Klaida patvirtinant jūsų antrąjį faktorių",
    "Access through untrusted domain" : "Prieiga iš nepatikimo domeno",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Susisiekite su savo administratoriumi. Jeigu jūs esate administratorius, pataisykite \"trusted_domains\" nustatymą config/config.php faile, kaip tai parodyta pavyzdyje, config.sample.php faile.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Tolimesnę informaciją apie tai, kaip tai konfigūruoti, galite rasti %1$sdokumentacijoje%2$s.",
    "App update required" : "Reikalingas programėlės atnaujinimas",
    "%1$s will be updated to version %2$s" : "%1$s bus atnaujinta į versiją %2$s",
    "The following apps will be updated:" : "Bus atnaujintos šios programėlės:",
    "These incompatible apps will be disabled:" : "Bus išjungtos šios nesuderinamos programėlės:",
    "The theme %s has been disabled." : "Apipavidalinimas %s buvo išjungtas.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Prieš tęsdami, įsitikinkite, kad pasidarėte duomenų bazės, konfigūracijos aplanko bei duomenų aplanko atsarginę kopiją.",
    "Start update" : "Pradėti atnaujinimą",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Naudodami didesnius diegimus ir norėdami išvengti laukimo laiko, vietoj to, savo diegimo kataloge galite paleisti šią komandą:",
    "Detailed logs" : "Išsamūs žurnalai",
    "Update needed" : "Reikalingas atnaujinimas",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Prireikus pagalbos, žiūrėkite  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciją</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Suprantu, kad atnaujinimui naudodamas vartotojo aplinką, rizikuoju, kad sistemos darbas sutriks ir prisijungę vartotojai gali netekti duomenų, turiu atsarginę duomenų kopiją ir žinau, kaip atstatyti duomenis nesėkmės atveju.",
    "Upgrade via web on my own risk" : "Atnaujinti per interneto naršyklę prisiimant riziką",
    "Maintenance mode" : "Techninės priežiūros veiksena",
    "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
    "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
    "Error occurred while checking server setup" : "Tikrinant serverio sąranką, įvyko klaida",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Išsamesnei informacijai, žiūrėkite {linkstart}dokumentaciją ↗{linkend}.",
    "unknown text" : "nežinomas tekstas",
    "Hello world!" : "Sveikas, pasauli!",
    "sunny" : "saulėta",
    "Hello {name}, the weather is {weather}" : "Sveiki {name}, šiandien yra {weather}",
    "Hello {name}" : "Sveiki, {name},",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Paieškos rezultatai:<script>alert(1)</script></strong>",
    "new" : "naujas",
    "_download %n file_::_download %n files_" : ["atsisiųsti %n failą","atsisiųsti %n failus","atsisiųsti %n failų","atsisiųsti %n failą"],
    "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
    "Searching …" : "Ieškoma…",
    "Logging in …" : "Prisijungiama …",
    "Loading apps …" : "Įkeliamos programėlės…",
    "Installing apps …" : "Įdiegiamos programėlės…",
    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
    "Looking for {term} …" : "Ieškoma {term} ...",
    "Search contacts …" : "Ieškoti adresatų…",
    "Loading more results …" : "Įkeliama daugiau rezultatų…",
    "Search {types} …" : "Ieškoti {types}…",
    "Saving …" : "Įrašoma…",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "No action available" : "Jokie veiksmai negalimi",
    "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
    "Non-existing tag #{tag}" : "Neegzistuojanti žyma #{tag}",
    "Restricted" : "Apribota",
    "Delete" : "Ištrinti",
    "Rename" : "Pervadinti",
    "Collaborative tags" : "Bendradarbiavimo žymos",
    "No tags found" : "Nerasta jokių žymų",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
    "Show password" : "Rodyti slaptažodį",
    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
    "Configure the database" : "Konfigūruokite duomenų bazę",
    "Only %s is available." : "Yra prieinama tik %s.",
    "Database account" : "Duomenų bazės paskyra",
    "Installing …" : "Įdiegiama…"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
